from Products.Archetypes.Widget import PasswordWidget
from interfaces import MegamanicEditableTemplateObject

def setup(klass):
    schema = klass.schema
    enable_postback(schema)
    if MegamanicEditableTemplateObject.implementedBy(klass) and schema.has_key('subject'):
        schema.changeSchemataForField('subject', 'default')

def enable_postback(schema):
    """Enables postback for all schema fields, except password."""
    for field in schema.fields():
        if not field.widget.__class__ is PasswordWidget:
            field.widget._properties['postback'] = True



## Script (Python) "isMegamanicEditable"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##parameters=object=None
##

# Another hack needed because of portal_interfaces..

return False



from zope.interface import Interface

class MegamanicEditableObject(Interface):
    """Indicates whether this object has objects or
    fields for MegamanicEdit."""

    def isMegamanicEditable():
        "Exists and returns true if the object is MegamanicEditable"

    def getMegamanicEditableFields():
        "Returns an ordered list of editable fields (as strings)."

    def megamanicHackRequest():
        "Alters the request to edit multiple objects and fields."

    def megamanicHackRequestClear():
        "Clears the request after multiple editing of objects."

    def isMegamanicEditableTemplateObject(self):   
        """Returns true if object is a template object."""

class MegamanicEditableTemplateObject(MegamanicEditableObject):
    """Indicates whether this object has support
    for the MegamanicEditableTemplateObject class."""
    pass
